from batou.component import Component
from batou.lib.file import File
from batou.lib.nagios import Service
import os
import re


class BPServiceCheck(Service):

    def configure(self):
        for tag in self.tags:
            self.provide(tag, self)

        super(BPServiceCheck, self).configure()

    def format_as_bp_member(self):
        config_str = '{};{};'.format(self.host.name,
                                     self.description)
        return config_str


class NagiosBP(Component):

    namevar = 'title'

    description = None
    primary = True
    priority = 2
    warning = 0
    critical = 0
    checks = []

    sla = None
    customer_contacts = None

    def configure(self):

        if not self.description:
            self.description = self.title
        self.name = re.sub(r'\W', '_', self.title).lower()
        self.primary = int(self.primary)

    @property
    def members(self):
        return self.format_as_bp()

    def format_as_bp_member(self):
        config_str = '{};{};'.format(self.host.name,
                                     self.title)
        return config_str

    def format_as_bp(self):
        essential_str = ','.join(map(
            lambda x: x.format_as_bp_member() + '|',
            self.essential))

        non_essential_str = ','.join(map(
            lambda x: x.format_as_bp_member() + '&',
            self.non_essential))

        return ','.join([essential_str, non_essential_str])


class NagiosBPConfigFile(Component):

    """Generate a Nagios config snippet for Business Processes.

    The generated config needs to be copied to the Nagios server.
    """

    namevar = 'filename'

    bpi_cfg = os.path.join(os.path.dirname(__file__),
                           'resources', 'bpi.cfg')

    def configure(self):

        self += File(self.filename,
                     source=self.bpi_cfg,
                     mode=0o644,
                     is_template=True)

